pub fn decode_message(buf: &[u8]) -> Result<Message, FaucetError>Expand description
Decode a single pgoutput message from the start of buf.
The caller has already stripped the XLogData header. The first byte is the message kind discriminator.
pub fn decode_message(buf: &[u8]) -> Result<Message, FaucetError>Decode a single pgoutput message from the start of buf.
The caller has already stripped the XLogData header. The first byte is the message kind discriminator.