ensure_slot

Function ensure_slot 

pub async fn ensure_slot(
    _client: &Client,
    connection_url: &str,
    slot_name: &str,
    create_if_missing: bool,
    slot_type: SlotType,
) -> Result<(), FaucetError>
Ensure the replication slot exists.

If the slot already exists this is a no-op. If it does not exist and create_if_missing is true, the slot is created via pg_create_logical_replication_slot. If create_if_missing is false and the slot is absent, an error is returned.